View source: R/RNAseq_GSEAheatmaps.R
| RNAseq_GSEAheatmaps | R Documentation |
Make heatmaps from combined GSEA reports after EdgeR
RNAseq_GSEAheatmaps(
gsea_combined_profiles,
clean_names_regex = "EdgeR\\.TMM_Exact_|EdgeR\\.upperquartile_LRT_RUVr_|\\.rnk\\.NES",
scale_bounds = NULL,
reo_order_cols = NULL,
clust_row = TRUE,
clust_col = FALSE,
show_rownames = FALSE,
show_colnames = FALSE
)
gsea_combined_profiles |
[type: character, default: NULL] this is a path to a prepared excel file. This file should contian your combined reports (all comparisons from GSEA bound together; use Cristian's tool to combine reports. Then combine these reports into a single excel, each tab represents comparisons per pathway collection. |
clean_names_regex |
[type: character, default: "EdgeR\.TMM_Exact_|EdgeR\.upperquartile_LRT_RUVr_|\.rnk\.NES"] a regex expression to remove strings from the comparison names. Often comparisons are preceeeded by some prefix of the parameters of which the rank files were created, normalisation etc. |
scale_bounds |
[type: vector<numeric>, default: NULL] if provided will set the max and min of the scale for heatmaps; affects colour intensity. |
reo_order_cols |
[type: vector<numeric>, default: NULL] if provided will re-order the columns for every heatmap. You must know the order and number of columns you wish before supplying. |
clust_row |
[type: logical, default: FALSE] true uses pheatmap's clustering on rows; pathways. |
clust_col |
[type: logical, default: FALSE] true uses pheatmap's clustering on columns; comparisons. |
show_rownames |
[type: logical, default: FALSE] true shows the rownames; pathways. |
show_colnames |
[type: logical, default: FALSE] true shows the column names; comparisons. |
Your combined GSEA reports should look something like this:
path <- system.file(
"extdata",
"GSEA-combined-enrichment-profiles.xlsx",
package = "derecksLabTools"
)
heatmaps <- RNAseq_GSEAheatmaps(
path,
scale_bounds = NULL,
reo_order_cols = NULL,
clust_row = TRUE,
clust_col = FALSE,
show_rownames = TRUE,
show_colnames = TRUE
)
pdf("./hallmark-enrichment-heatmap.pdf", width = 7, height = 10)
print(heatmaps$hallmark)
dev.off()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.