| Volcano-class | R Documentation |
S4 class; Volcano data.table manipulated and prepared for plottingThis class takes in a data.table with specific columns in a specific format. Columns must contain: "feature" and "log2FC" columns. This data must also contain either or/and both "fdr", "p_value" columns.
Then this class manipulates this object to produce an S4 class who is ready for plotting and saves all settings used to prepare the data in adjacent slots.
You can then plot this object by simply calling plot(Volcano(data))
Volcano
datadata.table.
statisticcharacter; which column to use as a statistic filter - either "fdr" or "p_value".
statistic_cutoffnumeric.
log2_cutoffnumeric.
head_labelsnumeric; how many points to be labeled; sorts data and creates a label for only top n.
plot-Volcano
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.