| CombatRNAseq-class | R Documentation |
S4 class; does sva::ComBat_seq batch correctionS4 class; does sva::ComBat_seq batch correction
correcteddata.table.
batcheslist.
batch_mapdata.table.
qc_plotslist.
Dereck de Mezquita
This class with its constructor makes it easy to do batch correction. Simply provide the list of data.tables to the class instantiator. This will return the corrected dataset along with PCA plots of before and after in a list.
The data.tables must have the columns:
GeneID
GeneBiotype
GeneSymbol
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.