summariseSignatures: Summarise how many genes up and down from a combined...

View source: R/summariseSignatures.R

summariseSignaturesR Documentation

Summarise how many genes up and down from a combined signature file

Description

The combined signature file should be produced by CoarfaLab-tools; and of the format: first column for rownames, subsequent columns comparison names, values fold changes.

Usage

summariseSignatures(
  combined_signatures_file,
  output_file,
  gsub_rows_regex = "EdgeR\\.upperquartile_LRT_RUVr_|_FC_1\\.25_FDR_0\\.05"
)

Arguments

combined_signatures_file

[type: character] A combined signature file; produced by running CoarfaLab-tools: combineGeneSignatures.cc.py -g "sig.*" -o combined-sig &> log.combined-sig

output_file

[type: character] Output file, csv format.

Details

combined-sig.log2.png

Value

data.table


CoarfaBCM/derecksLabTools documentation built on April 3, 2022, 10:29 p.m.