View source: R/summariseSignatures.R
| summariseSignatures | R Documentation |
The combined signature file should be produced by CoarfaLab-tools; and of the format: first column for rownames, subsequent columns comparison names, values fold changes.
summariseSignatures( combined_signatures_file, output_file, gsub_rows_regex = "EdgeR\\.upperquartile_LRT_RUVr_|_FC_1\\.25_FDR_0\\.05" )
combined_signatures_file |
[type: character] A combined signature file; produced by running CoarfaLab-tools: |
output_file |
[type: character] Output file, csv format. |
data.table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.